.. highlight:: shell

============
Installation
============


Stable release
--------------

To install, run this command in your terminal:

.. code-block:: console

    $ pip install bikram

This is the recommended method of installation, as it will always install the most recent stable release. 


From sources
------------

The sources for Python Bikram Samwat can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/poudel/bikram

.. _Github repo: https://github.com/poudel/bikram
.. _tarball: https://github.com/poudel/bikram/tarball/master
